create or replace function test_btree_insert(logsize integer, fillersize int4)
returns void language plpgsql as
$$
declare
  beginwal pg_lsn;
  endwal pg_lsn;
  begintime timestamp;
  endtime timestamp;
  operations integer;
  colsize int4;
begin

  create temporary table atest (filler bytea) on commit drop;
  insert into atest select ('\x' || rpad(g::text, fillersize*2, '0'))::bytea from generate_series(1, 100000) g;

  create table testtbl(filler text);
  create index testtbl_btree on testtbl(filler);

  -- Run the tests
  operations = 0;
  beginwal = pg_current_xlog_insert_location();
  begintime = clock_timestamp();
  loop
    operations = operations + 100000;
    insert into testtbl select * from atest;
    endwal = pg_current_xlog_insert_location();
    exit when endwal - beginwal >= logsize;
  end loop;
  endtime = clock_timestamp();
  endwal = pg_current_xlog_insert_location();

  -- print result
  select pg_column_size(atest) into colsize from atest limit 1;
  insert into testresult (wal, description, operations, dur_s)
    values (endwal - beginwal, 'heap + btree insert ' || colsize, operations, extract(epoch from endtime - begintime));

  -- clean up
  drop table testtbl;
  drop table atest;
end;
$$;
