-- Compare patched vs. unpatched results.
--
-- To run:
-- 1. Run the test suite without the patch:
--   psql -f run.sql
--
-- 2. Rename the testresult table:
--   psql -f "alter table testresult rename to testresult_orig"
--
--
-- 3. Restart with patched version, and run the suite again
--
-- 4. Rename the results again:
--   psql -f "alter table testresult rename to testresult_patched"
--
-- 5. Run this script

-- WAL record stats
select o.description,
       o.wal/o.operations as "wal_per_op (orig)",
       p.wal/p.operations as "wal_per_op (patched)",
       round((p.wal/p.operations)::numeric / (o.wal / o.operations) * 100, 2) as "%"
from testresult_orig o, testresult_patched p
where o.testno = p.testno
and o.operations <= 100000;

-- Performance / record stats:

with testnos (testno) as (
  select testno from testresult_orig where operations > 100000
  union
  select testno from testresult_patched where operations > 100000
)
select description,
       dur_orig as "dur_us (orig)",
       dur_patched as "dur_us (patched)",
       round((dur_patched / dur_orig * 100)::numeric, 2) as "%"
from
(
  select o.description,
         (percentile_cont(0.10) within group (order by o.dur_s/o.operations)) * 1000000 as dur_orig,
         (percentile_cont(0.10) within group (order by p.dur_s/p.operations)) * 1000000 as dur_patched
  from testnos t
  left outer join testresult_orig o on o.testno = t.testno
  left outer join testresult_patched p on p.testno = t.testno
  group by o.description
) as t;
