create or replace function test_gin_insert(logsize integer, fastupdate boolean)
returns void language plpgsql as
$$
declare
  beginwal pg_lsn;
  endwal pg_lsn;
  begintime timestamp;
  endtime timestamp;
  operations integer;
  colsize int4;
  description text;
begin

  create table testtbl(iarray int[]);
  create index testtbl_gin on testtbl using gin (iarray);
  if not fastupdate then
    alter index testtbl_gin set (fastupdate=off);
  end if;

  -- Run the tests
  operations = 0;
  beginwal = pg_current_xlog_insert_location();
  begintime = clock_timestamp();
  loop
    operations = operations + 1000;

    -- Generates 1000 rows, with an array with 1-1000 elements each.
    insert into testtbl
      select a.a
        from generate_series(1, 1000) m,
        lateral (select array_agg(g) as a from generate_series(1, m) g) as a;

    endwal = pg_current_xlog_insert_location();
    exit when endwal - beginwal >= logsize;
  end loop;
  endtime = clock_timestamp();
  endwal = pg_current_xlog_insert_location();

  -- print result
  if fastupdate then
    description = 'heap + gin insert (fastupdate)';
  else
    description = 'heap + gin insert';
  end if;

  insert into testresult (wal, description, operations, dur_s)
    values (endwal - beginwal, description, operations, extract(epoch from endtime - begintime));

  -- clean up
  drop table testtbl;
end;
$$;
