-- Collect data about different operations and record sizes. The purpose
-- of these tests is to measure the WAL size of these operations, not so much
-- to measure the runtime. (hopefully the new format is not much more bulky).
select test_heap_insert (1000000, g) from generate_series(1, 10) g;
select test_heap_update (1000000, g, false) from generate_series(1, 10) g;
select test_heap_update (1000000, g, true) from generate_series(1, 10) g;
select test_btree_insert (1000000, g) from generate_series(1, 10) g;
select test_gin_insert(1000000, true);
select test_gin_insert(1000000, false);

-- Collect more data with a small WAL size. This is to measure the overhead
-- of the XLogRegister* function calls. The record size here is chosen so
-- that the WAL record has the same size with and without the patch - larger
-- records are obviously also slower to generate, and we don't want to
-- measure that. Repeat many times to ensure we have a repeatable result.
--
-- Each test generates a bit over 10MB of WAL. That's enough to fit in
-- wal_buffers='16MB', so that we test the XLogRegister* overhead, not
-- flushing the WAL to disk or OS buffers.
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);

checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
checkpoint; select test_heap_insert(10000000, 5);
